pub struct TaskManager {
pub tasks_refactored: Vaults,
pub tags: HashSet<String>,
pub current_filter: Option<Filter>,
/* private fields */
}Fields
tasks_refactored: Vaultscurrent_filter: Option<Filter>Implementations
Sourceimpl TaskManager
impl TaskManager
Sourcepub fn load_from_config(config: &TasksConfig) -> Result<Self>
pub fn load_from_config(config: &TasksConfig) -> Result<Self>
Loads a vault from a Config and returns a TaskManager.
Errors
This function will return an error if the vault can’t be loaded.
pub fn new_without_loading(config: &TasksConfig) -> Self
Sourcepub fn reload(&mut self, config: &TasksConfig) -> Result<()>
pub fn reload(&mut self, config: &TasksConfig) -> Result<()>
Reloads the VaultData from file system.
Errors
This function will return an error if the vault can’t be parsed, or if tasks can’t be fixed (relative dates are replaced by fixed dates for example).
Sourcepub fn map_file_entries(
tasks: &Vaults,
f: &mut impl FnMut(&FileEntryNode) -> FileEntryNode,
) -> Vaults
pub fn map_file_entries( tasks: &Vaults, f: &mut impl FnMut(&FileEntryNode) -> FileEntryNode, ) -> Vaults
Explores every NewFileEntry from the vault and applies the given function f on it.
Explores the vault and fills a &mut HashSet<String> with every tags found.
Sourcepub fn resolve_path(&self, path: &[String]) -> Result<Found>
pub fn resolve_path(&self, path: &[String]) -> Result<Found>
Follows the path to retrieve the correct VaultData.
Errors
Will return an error if the vault is empty or the path cannot be resolved
Sourcepub fn can_enter(&mut self, selected_header_path: &[String]) -> bool
pub fn can_enter(&mut self, selected_header_path: &[String]) -> bool
Whether the path resolves to something that can be entered or not. Directories, Headers and Tasks with subtasks can be entered.
Sourcepub fn add_task(
&mut self,
task_input: &str,
filepath_opt: Option<(bool, PathBuf)>,
) -> Result<()>
pub fn add_task( &mut self, task_input: &str, filepath_opt: Option<(bool, PathBuf)>, ) -> Result<()>
Adds a new task to the vault from a raw task input string.
Task will be added to the specified file or the default file configured in the TasksConfig .
Errors
Will return an error if the task cannot be parsed or if it cannot be written to the vault.